@@ -2,7 +2,6 @@ from crosslingual_coreference import Predictor
 
 from .data import texts
 
-predictor = Predictor(language='nl_core_news_sm')
+predictor = Predictor(language="nl_core_news_sm")
 
 print(predictor.pipe(texts))
-
